==> keepassx_0.2.2.orig.tar.gz: keepassx-0.2.2/src/dialogs/DatabaseSettingsDlg.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Tarek Saidi                                     *
 *   tarek@linux                                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef DBSETTINGSDLG_H
#define DBSETTINGSDLG_H
#include "ui_DatabaseSettingsDlg.h"
#include "main.h"
#include "Database.h"
//Added by qt3to4:
#include <QShowEvent>

class CDbSettingsDlg : public QDialog, public Ui_dbsettingdlg_base
{
  Q_OBJECT

public:
  CDbSettingsDlg(QWidget* parent,Database* db, bool modal = FALSE, Qt::WFlags fl = 0 );
  ~CDbSettingsDlg();
   virtual void showEvent(QShowEvent *);
  /*$PUBLIC_FUNCTIONS$*/

public slots:
  /*$PUBLIC_SLOTS$*/

protected:
  /*$PROTECTED_FUNCTIONS$*/

protected slots:
  /*$PROTECTED_SLOTS$*/

public slots:
    virtual void OnCancel();
    virtual void OnOK();

private:
   Database* database;
};

#endif

==> keepassx_0.3.3.orig.tar.gz: keepassx-0.3.3/src/dialogs/DatabaseSettingsDlg.h <==
/***************************************************************************
 *   Copyright (C) 2005-2006 by Tarek Saidi                                *
 *   tarek.saidi@arcor.de                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; version 2 of the License.               *

 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
#ifndef DBSETTINGSDLG_H
#define DBSETTINGSDLG_H

#include "ui_DatabaseSettingsDlg.h"

class CDbSettingsDlg : public QDialog, private Ui_DatabaseSettingsDlg
{
	Q_OBJECT
	public:
  		CDbSettingsDlg(QWidget* parent,IDatabase* db, bool modal = FALSE, Qt::WFlags fl = 0 );
  		~CDbSettingsDlg();
		virtual void paintEvent(QPaintEvent *);

	private slots:
    	void OnCancel();
    	void OnOK();
		void OnBenchmark();

	private:
		IKdbSettings* database;
		QPixmap BannerPixmap;
};

#endif
